@@ -28,7 +28,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 
 # Preloaded methods go here.
@@ -43,7 +43,6 @@ sub new {
 
 sub drivers {
 	my $self = shift;
-	$self->{DRIVERS} = [];
 	while ($_ = shift) {  push @{$self->{DRIVERS}}, $_; }
 	foreach my $driver ( @{ $self->{DRIVERS} }) {
 		require "WWW/Scraper/ISBN/".$driver."_Driver.pm";
@@ -51,6 +50,12 @@ sub drivers {
 	return @{ $self->{DRIVERS} };
 }
 
+sub reset_drivers {
+	my $self = shift;
+	$self->{DRIVERS} = [];
+	return @{ $self->{DRIVERS} };
+}
+
 sub search {
 	my $self = shift;
 	my $isbn = shift;
@@ -148,6 +153,12 @@ When this method is called, it loads the specified drivers using 'require'.
 
 Must be set before C<search()> method is called.
 
+=item C<reset_drivers>
+
+   $scraper->reset_drivers;
+
+Sets the list of drivers to an empty array.  Will disable search feature until a new driver is specified.
+
 =item C<search($isbn)>
 
    my $record = $scraper->search("123456789X");
